@@ -1,15 +1,31 @@
 use strict;
 use warnings;
 package Mixin::Linewise;
+{
+  $Mixin::Linewise::VERSION = '0.104';
+}
+# ABSTRACT: write your linewise code for handles; this does the rest
 use 5.006;
-our $VERSION = '0.003';
 use Carp ();
 Carp::confess "not meant to be loaded";
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Mixin::Linewise - write your linewise code for handles; this does the rest
 
+=head1 VERSION
+
+version 0.104
+
 =head1 DESCRIPTION
 
 It's boring to deal with opening files for IO, converting strings to
@@ -17,25 +33,15 @@ handle-like objects, and all that.  With L<Mixin::Linewise::Readers> and
 L<Mixin::Linewise::Writers>, you can just write a method to handle handles, and
 methods for handling strings and filenames are added for you.
 
-=head1 BUGS
-
-Bugs should be reported via the CPAN bug tracker at
-
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Mixin-Linewise>
-
-For other issues, or commercial enhancement or support, contact the author.
-
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< E<lt>rjbs@cpan.orgE<gt> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2008, Ricardo SIGNES.
+This software is copyright (c) 2008 by Ricardo SIGNES.
 
-This program is free software; you may redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
